# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 instances: pulumi.Input['ClusterJobFlowInstancesConfigArgs'],
                 job_flow_role: pulumi.Input[str],
                 name: pulumi.Input[str],
                 service_role: pulumi.Input[str],
                 additional_info: Optional[Any] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationArgs']]]] = None,
                 auto_scaling_role: Optional[pulumi.Input[str]] = None,
                 bootstrap_actions: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapActionConfigArgs']]]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterConfigurationArgs']]]] = None,
                 custom_ami_id: Optional[pulumi.Input[str]] = None,
                 ebs_root_volume_size: Optional[pulumi.Input[int]] = None,
                 kerberos_attributes: Optional[pulumi.Input['ClusterKerberosAttributesArgs']] = None,
                 log_encryption_kms_key_id: Optional[pulumi.Input[str]] = None,
                 log_uri: Optional[pulumi.Input[str]] = None,
                 managed_scaling_policy: Optional[pulumi.Input['ClusterManagedScalingPolicyArgs']] = None,
                 release_label: Optional[pulumi.Input[str]] = None,
                 scale_down_behavior: Optional[pulumi.Input[str]] = None,
                 security_configuration: Optional[pulumi.Input[str]] = None,
                 step_concurrency_level: Optional[pulumi.Input[int]] = None,
                 steps: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterStepConfigArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]] = None,
                 visible_to_all_users: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        """
        pulumi.set(__self__, "instances", instances)
        pulumi.set(__self__, "job_flow_role", job_flow_role)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "service_role", service_role)
        if additional_info is not None:
            pulumi.set(__self__, "additional_info", additional_info)
        if applications is not None:
            pulumi.set(__self__, "applications", applications)
        if auto_scaling_role is not None:
            pulumi.set(__self__, "auto_scaling_role", auto_scaling_role)
        if bootstrap_actions is not None:
            pulumi.set(__self__, "bootstrap_actions", bootstrap_actions)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)
        if custom_ami_id is not None:
            pulumi.set(__self__, "custom_ami_id", custom_ami_id)
        if ebs_root_volume_size is not None:
            pulumi.set(__self__, "ebs_root_volume_size", ebs_root_volume_size)
        if kerberos_attributes is not None:
            pulumi.set(__self__, "kerberos_attributes", kerberos_attributes)
        if log_encryption_kms_key_id is not None:
            pulumi.set(__self__, "log_encryption_kms_key_id", log_encryption_kms_key_id)
        if log_uri is not None:
            pulumi.set(__self__, "log_uri", log_uri)
        if managed_scaling_policy is not None:
            pulumi.set(__self__, "managed_scaling_policy", managed_scaling_policy)
        if release_label is not None:
            pulumi.set(__self__, "release_label", release_label)
        if scale_down_behavior is not None:
            pulumi.set(__self__, "scale_down_behavior", scale_down_behavior)
        if security_configuration is not None:
            pulumi.set(__self__, "security_configuration", security_configuration)
        if step_concurrency_level is not None:
            pulumi.set(__self__, "step_concurrency_level", step_concurrency_level)
        if steps is not None:
            pulumi.set(__self__, "steps", steps)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if visible_to_all_users is not None:
            pulumi.set(__self__, "visible_to_all_users", visible_to_all_users)

    @property
    @pulumi.getter
    def instances(self) -> pulumi.Input['ClusterJobFlowInstancesConfigArgs']:
        return pulumi.get(self, "instances")

    @instances.setter
    def instances(self, value: pulumi.Input['ClusterJobFlowInstancesConfigArgs']):
        pulumi.set(self, "instances", value)

    @property
    @pulumi.getter(name="jobFlowRole")
    def job_flow_role(self) -> pulumi.Input[str]:
        return pulumi.get(self, "job_flow_role")

    @job_flow_role.setter
    def job_flow_role(self, value: pulumi.Input[str]):
        pulumi.set(self, "job_flow_role", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="serviceRole")
    def service_role(self) -> pulumi.Input[str]:
        return pulumi.get(self, "service_role")

    @service_role.setter
    def service_role(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_role", value)

    @property
    @pulumi.getter(name="additionalInfo")
    def additional_info(self) -> Optional[Any]:
        return pulumi.get(self, "additional_info")

    @additional_info.setter
    def additional_info(self, value: Optional[Any]):
        pulumi.set(self, "additional_info", value)

    @property
    @pulumi.getter
    def applications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationArgs']]]]:
        return pulumi.get(self, "applications")

    @applications.setter
    def applications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationArgs']]]]):
        pulumi.set(self, "applications", value)

    @property
    @pulumi.getter(name="autoScalingRole")
    def auto_scaling_role(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "auto_scaling_role")

    @auto_scaling_role.setter
    def auto_scaling_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_scaling_role", value)

    @property
    @pulumi.getter(name="bootstrapActions")
    def bootstrap_actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapActionConfigArgs']]]]:
        return pulumi.get(self, "bootstrap_actions")

    @bootstrap_actions.setter
    def bootstrap_actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapActionConfigArgs']]]]):
        pulumi.set(self, "bootstrap_actions", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterConfigurationArgs']]]]:
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)

    @property
    @pulumi.getter(name="customAmiId")
    def custom_ami_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "custom_ami_id")

    @custom_ami_id.setter
    def custom_ami_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "custom_ami_id", value)

    @property
    @pulumi.getter(name="ebsRootVolumeSize")
    def ebs_root_volume_size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "ebs_root_volume_size")

    @ebs_root_volume_size.setter
    def ebs_root_volume_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ebs_root_volume_size", value)

    @property
    @pulumi.getter(name="kerberosAttributes")
    def kerberos_attributes(self) -> Optional[pulumi.Input['ClusterKerberosAttributesArgs']]:
        return pulumi.get(self, "kerberos_attributes")

    @kerberos_attributes.setter
    def kerberos_attributes(self, value: Optional[pulumi.Input['ClusterKerberosAttributesArgs']]):
        pulumi.set(self, "kerberos_attributes", value)

    @property
    @pulumi.getter(name="logEncryptionKmsKeyId")
    def log_encryption_kms_key_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "log_encryption_kms_key_id")

    @log_encryption_kms_key_id.setter
    def log_encryption_kms_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_encryption_kms_key_id", value)

    @property
    @pulumi.getter(name="logUri")
    def log_uri(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "log_uri")

    @log_uri.setter
    def log_uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_uri", value)

    @property
    @pulumi.getter(name="managedScalingPolicy")
    def managed_scaling_policy(self) -> Optional[pulumi.Input['ClusterManagedScalingPolicyArgs']]:
        return pulumi.get(self, "managed_scaling_policy")

    @managed_scaling_policy.setter
    def managed_scaling_policy(self, value: Optional[pulumi.Input['ClusterManagedScalingPolicyArgs']]):
        pulumi.set(self, "managed_scaling_policy", value)

    @property
    @pulumi.getter(name="releaseLabel")
    def release_label(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "release_label")

    @release_label.setter
    def release_label(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "release_label", value)

    @property
    @pulumi.getter(name="scaleDownBehavior")
    def scale_down_behavior(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "scale_down_behavior")

    @scale_down_behavior.setter
    def scale_down_behavior(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scale_down_behavior", value)

    @property
    @pulumi.getter(name="securityConfiguration")
    def security_configuration(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "security_configuration")

    @security_configuration.setter
    def security_configuration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_configuration", value)

    @property
    @pulumi.getter(name="stepConcurrencyLevel")
    def step_concurrency_level(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "step_concurrency_level")

    @step_concurrency_level.setter
    def step_concurrency_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "step_concurrency_level", value)

    @property
    @pulumi.getter
    def steps(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterStepConfigArgs']]]]:
        return pulumi.get(self, "steps")

    @steps.setter
    def steps(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterStepConfigArgs']]]]):
        pulumi.set(self, "steps", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="visibleToAllUsers")
    def visible_to_all_users(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "visible_to_all_users")

    @visible_to_all_users.setter
    def visible_to_all_users(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "visible_to_all_users", value)


warnings.warn("""Cluster is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)


class Cluster(pulumi.CustomResource):
    warnings.warn("""Cluster is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_info: Optional[Any] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationArgs']]]]] = None,
                 auto_scaling_role: Optional[pulumi.Input[str]] = None,
                 bootstrap_actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapActionConfigArgs']]]]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterConfigurationArgs']]]]] = None,
                 custom_ami_id: Optional[pulumi.Input[str]] = None,
                 ebs_root_volume_size: Optional[pulumi.Input[int]] = None,
                 instances: Optional[pulumi.Input[pulumi.InputType['ClusterJobFlowInstancesConfigArgs']]] = None,
                 job_flow_role: Optional[pulumi.Input[str]] = None,
                 kerberos_attributes: Optional[pulumi.Input[pulumi.InputType['ClusterKerberosAttributesArgs']]] = None,
                 log_encryption_kms_key_id: Optional[pulumi.Input[str]] = None,
                 log_uri: Optional[pulumi.Input[str]] = None,
                 managed_scaling_policy: Optional[pulumi.Input[pulumi.InputType['ClusterManagedScalingPolicyArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 release_label: Optional[pulumi.Input[str]] = None,
                 scale_down_behavior: Optional[pulumi.Input[str]] = None,
                 security_configuration: Optional[pulumi.Input[str]] = None,
                 service_role: Optional[pulumi.Input[str]] = None,
                 step_concurrency_level: Optional[pulumi.Input[int]] = None,
                 steps: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterStepConfigArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterTagArgs']]]]] = None,
                 visible_to_all_users: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Resource Type definition for AWS::EMR::Cluster

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource Type definition for AWS::EMR::Cluster

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_info: Optional[Any] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationArgs']]]]] = None,
                 auto_scaling_role: Optional[pulumi.Input[str]] = None,
                 bootstrap_actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapActionConfigArgs']]]]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterConfigurationArgs']]]]] = None,
                 custom_ami_id: Optional[pulumi.Input[str]] = None,
                 ebs_root_volume_size: Optional[pulumi.Input[int]] = None,
                 instances: Optional[pulumi.Input[pulumi.InputType['ClusterJobFlowInstancesConfigArgs']]] = None,
                 job_flow_role: Optional[pulumi.Input[str]] = None,
                 kerberos_attributes: Optional[pulumi.Input[pulumi.InputType['ClusterKerberosAttributesArgs']]] = None,
                 log_encryption_kms_key_id: Optional[pulumi.Input[str]] = None,
                 log_uri: Optional[pulumi.Input[str]] = None,
                 managed_scaling_policy: Optional[pulumi.Input[pulumi.InputType['ClusterManagedScalingPolicyArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 release_label: Optional[pulumi.Input[str]] = None,
                 scale_down_behavior: Optional[pulumi.Input[str]] = None,
                 security_configuration: Optional[pulumi.Input[str]] = None,
                 service_role: Optional[pulumi.Input[str]] = None,
                 step_concurrency_level: Optional[pulumi.Input[int]] = None,
                 steps: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterStepConfigArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterTagArgs']]]]] = None,
                 visible_to_all_users: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        pulumi.log.warn("""Cluster is deprecated: Cluster is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""")
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["additional_info"] = additional_info
            __props__.__dict__["applications"] = applications
            __props__.__dict__["auto_scaling_role"] = auto_scaling_role
            __props__.__dict__["bootstrap_actions"] = bootstrap_actions
            __props__.__dict__["configurations"] = configurations
            __props__.__dict__["custom_ami_id"] = custom_ami_id
            __props__.__dict__["ebs_root_volume_size"] = ebs_root_volume_size
            if instances is None and not opts.urn:
                raise TypeError("Missing required property 'instances'")
            __props__.__dict__["instances"] = instances
            if job_flow_role is None and not opts.urn:
                raise TypeError("Missing required property 'job_flow_role'")
            __props__.__dict__["job_flow_role"] = job_flow_role
            __props__.__dict__["kerberos_attributes"] = kerberos_attributes
            __props__.__dict__["log_encryption_kms_key_id"] = log_encryption_kms_key_id
            __props__.__dict__["log_uri"] = log_uri
            __props__.__dict__["managed_scaling_policy"] = managed_scaling_policy
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["release_label"] = release_label
            __props__.__dict__["scale_down_behavior"] = scale_down_behavior
            __props__.__dict__["security_configuration"] = security_configuration
            if service_role is None and not opts.urn:
                raise TypeError("Missing required property 'service_role'")
            __props__.__dict__["service_role"] = service_role
            __props__.__dict__["step_concurrency_level"] = step_concurrency_level
            __props__.__dict__["steps"] = steps
            __props__.__dict__["tags"] = tags
            __props__.__dict__["visible_to_all_users"] = visible_to_all_users
            __props__.__dict__["master_public_dns"] = None
        super(Cluster, __self__).__init__(
            'aws-native:emr:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = ClusterArgs.__new__(ClusterArgs)

        __props__.__dict__["additional_info"] = None
        __props__.__dict__["applications"] = None
        __props__.__dict__["auto_scaling_role"] = None
        __props__.__dict__["bootstrap_actions"] = None
        __props__.__dict__["configurations"] = None
        __props__.__dict__["custom_ami_id"] = None
        __props__.__dict__["ebs_root_volume_size"] = None
        __props__.__dict__["instances"] = None
        __props__.__dict__["job_flow_role"] = None
        __props__.__dict__["kerberos_attributes"] = None
        __props__.__dict__["log_encryption_kms_key_id"] = None
        __props__.__dict__["log_uri"] = None
        __props__.__dict__["managed_scaling_policy"] = None
        __props__.__dict__["master_public_dns"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["release_label"] = None
        __props__.__dict__["scale_down_behavior"] = None
        __props__.__dict__["security_configuration"] = None
        __props__.__dict__["service_role"] = None
        __props__.__dict__["step_concurrency_level"] = None
        __props__.__dict__["steps"] = None
        __props__.__dict__["tags"] = None
        __props__.__dict__["visible_to_all_users"] = None
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalInfo")
    def additional_info(self) -> pulumi.Output[Optional[Any]]:
        return pulumi.get(self, "additional_info")

    @property
    @pulumi.getter
    def applications(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterApplication']]]:
        return pulumi.get(self, "applications")

    @property
    @pulumi.getter(name="autoScalingRole")
    def auto_scaling_role(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "auto_scaling_role")

    @property
    @pulumi.getter(name="bootstrapActions")
    def bootstrap_actions(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterBootstrapActionConfig']]]:
        return pulumi.get(self, "bootstrap_actions")

    @property
    @pulumi.getter
    def configurations(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterConfiguration']]]:
        return pulumi.get(self, "configurations")

    @property
    @pulumi.getter(name="customAmiId")
    def custom_ami_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "custom_ami_id")

    @property
    @pulumi.getter(name="ebsRootVolumeSize")
    def ebs_root_volume_size(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "ebs_root_volume_size")

    @property
    @pulumi.getter
    def instances(self) -> pulumi.Output['outputs.ClusterJobFlowInstancesConfig']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="jobFlowRole")
    def job_flow_role(self) -> pulumi.Output[str]:
        return pulumi.get(self, "job_flow_role")

    @property
    @pulumi.getter(name="kerberosAttributes")
    def kerberos_attributes(self) -> pulumi.Output[Optional['outputs.ClusterKerberosAttributes']]:
        return pulumi.get(self, "kerberos_attributes")

    @property
    @pulumi.getter(name="logEncryptionKmsKeyId")
    def log_encryption_kms_key_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "log_encryption_kms_key_id")

    @property
    @pulumi.getter(name="logUri")
    def log_uri(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "log_uri")

    @property
    @pulumi.getter(name="managedScalingPolicy")
    def managed_scaling_policy(self) -> pulumi.Output[Optional['outputs.ClusterManagedScalingPolicy']]:
        return pulumi.get(self, "managed_scaling_policy")

    @property
    @pulumi.getter(name="masterPublicDNS")
    def master_public_dns(self) -> pulumi.Output[str]:
        return pulumi.get(self, "master_public_dns")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="releaseLabel")
    def release_label(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "release_label")

    @property
    @pulumi.getter(name="scaleDownBehavior")
    def scale_down_behavior(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "scale_down_behavior")

    @property
    @pulumi.getter(name="securityConfiguration")
    def security_configuration(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "security_configuration")

    @property
    @pulumi.getter(name="serviceRole")
    def service_role(self) -> pulumi.Output[str]:
        return pulumi.get(self, "service_role")

    @property
    @pulumi.getter(name="stepConcurrencyLevel")
    def step_concurrency_level(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "step_concurrency_level")

    @property
    @pulumi.getter
    def steps(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterStepConfig']]]:
        return pulumi.get(self, "steps")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterTag']]]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="visibleToAllUsers")
    def visible_to_all_users(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "visible_to_all_users")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ConnectorDefinitionConnectorDefinitionVersionArgs',
    'ConnectorDefinitionConnectorArgs',
    'ConnectorDefinitionVersionConnectorArgs',
    'CoreDefinitionCoreDefinitionVersionArgs',
    'CoreDefinitionCoreArgs',
    'CoreDefinitionVersionCoreArgs',
    'DeviceDefinitionDeviceDefinitionVersionArgs',
    'DeviceDefinitionDeviceArgs',
    'DeviceDefinitionVersionDeviceArgs',
    'FunctionDefinitionDefaultConfigArgs',
    'FunctionDefinitionEnvironmentArgs',
    'FunctionDefinitionExecutionArgs',
    'FunctionDefinitionFunctionConfigurationArgs',
    'FunctionDefinitionFunctionDefinitionVersionArgs',
    'FunctionDefinitionFunctionArgs',
    'FunctionDefinitionResourceAccessPolicyArgs',
    'FunctionDefinitionRunAsArgs',
    'FunctionDefinitionVersionDefaultConfigArgs',
    'FunctionDefinitionVersionEnvironmentArgs',
    'FunctionDefinitionVersionExecutionArgs',
    'FunctionDefinitionVersionFunctionConfigurationArgs',
    'FunctionDefinitionVersionFunctionArgs',
    'FunctionDefinitionVersionResourceAccessPolicyArgs',
    'FunctionDefinitionVersionRunAsArgs',
    'GroupGroupVersionArgs',
    'LoggerDefinitionLoggerDefinitionVersionArgs',
    'LoggerDefinitionLoggerArgs',
    'LoggerDefinitionVersionLoggerArgs',
    'ResourceDefinitionGroupOwnerSettingArgs',
    'ResourceDefinitionLocalDeviceResourceDataArgs',
    'ResourceDefinitionLocalVolumeResourceDataArgs',
    'ResourceDefinitionResourceDataContainerArgs',
    'ResourceDefinitionResourceDefinitionVersionArgs',
    'ResourceDefinitionResourceDownloadOwnerSettingArgs',
    'ResourceDefinitionResourceInstanceArgs',
    'ResourceDefinitionS3MachineLearningModelResourceDataArgs',
    'ResourceDefinitionSageMakerMachineLearningModelResourceDataArgs',
    'ResourceDefinitionSecretsManagerSecretResourceDataArgs',
    'ResourceDefinitionVersionGroupOwnerSettingArgs',
    'ResourceDefinitionVersionLocalDeviceResourceDataArgs',
    'ResourceDefinitionVersionLocalVolumeResourceDataArgs',
    'ResourceDefinitionVersionResourceDataContainerArgs',
    'ResourceDefinitionVersionResourceDownloadOwnerSettingArgs',
    'ResourceDefinitionVersionResourceInstanceArgs',
    'ResourceDefinitionVersionS3MachineLearningModelResourceDataArgs',
    'ResourceDefinitionVersionSageMakerMachineLearningModelResourceDataArgs',
    'ResourceDefinitionVersionSecretsManagerSecretResourceDataArgs',
    'SubscriptionDefinitionSubscriptionDefinitionVersionArgs',
    'SubscriptionDefinitionSubscriptionArgs',
    'SubscriptionDefinitionVersionSubscriptionArgs',
]

@pulumi.input_type
class ConnectorDefinitionConnectorDefinitionVersionArgs:
    def __init__(__self__, *,
                 connectors: pulumi.Input[Sequence[pulumi.Input['ConnectorDefinitionConnectorArgs']]]):
        pulumi.set(__self__, "connectors", connectors)

    @property
    @pulumi.getter
    def connectors(self) -> pulumi.Input[Sequence[pulumi.Input['ConnectorDefinitionConnectorArgs']]]:
        return pulumi.get(self, "connectors")

    @connectors.setter
    def connectors(self, value: pulumi.Input[Sequence[pulumi.Input['ConnectorDefinitionConnectorArgs']]]):
        pulumi.set(self, "connectors", value)


@pulumi.input_type
class ConnectorDefinitionConnectorArgs:
    def __init__(__self__, *,
                 connector_arn: pulumi.Input[str],
                 id: pulumi.Input[str],
                 parameters: Optional[Any] = None):
        pulumi.set(__self__, "connector_arn", connector_arn)
        pulumi.set(__self__, "id", id)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)

    @property
    @pulumi.getter(name="connectorArn")
    def connector_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "connector_arn")

    @connector_arn.setter
    def connector_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "connector_arn", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[Any]:
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[Any]):
        pulumi.set(self, "parameters", value)


@pulumi.input_type
class ConnectorDefinitionVersionConnectorArgs:
    def __init__(__self__, *,
                 connector_arn: pulumi.Input[str],
                 id: pulumi.Input[str],
                 parameters: Optional[Any] = None):
        pulumi.set(__self__, "connector_arn", connector_arn)
        pulumi.set(__self__, "id", id)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)

    @property
    @pulumi.getter(name="connectorArn")
    def connector_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "connector_arn")

    @connector_arn.setter
    def connector_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "connector_arn", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[Any]:
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[Any]):
        pulumi.set(self, "parameters", value)


@pulumi.input_type
class CoreDefinitionCoreDefinitionVersionArgs:
    def __init__(__self__, *,
                 cores: pulumi.Input[Sequence[pulumi.Input['CoreDefinitionCoreArgs']]]):
        pulumi.set(__self__, "cores", cores)

    @property
    @pulumi.getter
    def cores(self) -> pulumi.Input[Sequence[pulumi.Input['CoreDefinitionCoreArgs']]]:
        return pulumi.get(self, "cores")

    @cores.setter
    def cores(self, value: pulumi.Input[Sequence[pulumi.Input['CoreDefinitionCoreArgs']]]):
        pulumi.set(self, "cores", value)


@pulumi.input_type
class CoreDefinitionCoreArgs:
    def __init__(__self__, *,
                 certificate_arn: pulumi.Input[str],
                 id: pulumi.Input[str],
                 thing_arn: pulumi.Input[str],
                 sync_shadow: Optional[pulumi.Input[bool]] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "certificate_arn")

    @certificate_arn.setter
    def certificate_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "certificate_arn", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "thing_arn")

    @thing_arn.setter
    def thing_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "thing_arn", value)

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "sync_shadow")

    @sync_shadow.setter
    def sync_shadow(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_shadow", value)


@pulumi.input_type
class CoreDefinitionVersionCoreArgs:
    def __init__(__self__, *,
                 certificate_arn: pulumi.Input[str],
                 id: pulumi.Input[str],
                 thing_arn: pulumi.Input[str],
                 sync_shadow: Optional[pulumi.Input[bool]] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "certificate_arn")

    @certificate_arn.setter
    def certificate_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "certificate_arn", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "thing_arn")

    @thing_arn.setter
    def thing_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "thing_arn", value)

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "sync_shadow")

    @sync_shadow.setter
    def sync_shadow(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_shadow", value)


@pulumi.input_type
class DeviceDefinitionDeviceDefinitionVersionArgs:
    def __init__(__self__, *,
                 devices: pulumi.Input[Sequence[pulumi.Input['DeviceDefinitionDeviceArgs']]]):
        pulumi.set(__self__, "devices", devices)

    @property
    @pulumi.getter
    def devices(self) -> pulumi.Input[Sequence[pulumi.Input['DeviceDefinitionDeviceArgs']]]:
        return pulumi.get(self, "devices")

    @devices.setter
    def devices(self, value: pulumi.Input[Sequence[pulumi.Input['DeviceDefinitionDeviceArgs']]]):
        pulumi.set(self, "devices", value)


@pulumi.input_type
class DeviceDefinitionDeviceArgs:
    def __init__(__self__, *,
                 certificate_arn: pulumi.Input[str],
                 id: pulumi.Input[str],
                 thing_arn: pulumi.Input[str],
                 sync_shadow: Optional[pulumi.Input[bool]] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "certificate_arn")

    @certificate_arn.setter
    def certificate_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "certificate_arn", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "thing_arn")

    @thing_arn.setter
    def thing_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "thing_arn", value)

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "sync_shadow")

    @sync_shadow.setter
    def sync_shadow(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_shadow", value)


@pulumi.input_type
class DeviceDefinitionVersionDeviceArgs:
    def __init__(__self__, *,
                 certificate_arn: pulumi.Input[str],
                 id: pulumi.Input[str],
                 thing_arn: pulumi.Input[str],
                 sync_shadow: Optional[pulumi.Input[bool]] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "certificate_arn")

    @certificate_arn.setter
    def certificate_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "certificate_arn", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "thing_arn")

    @thing_arn.setter
    def thing_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "thing_arn", value)

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "sync_shadow")

    @sync_shadow.setter
    def sync_shadow(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_shadow", value)


@pulumi.input_type
class FunctionDefinitionDefaultConfigArgs:
    def __init__(__self__, *,
                 execution: pulumi.Input['FunctionDefinitionExecutionArgs']):
        pulumi.set(__self__, "execution", execution)

    @property
    @pulumi.getter
    def execution(self) -> pulumi.Input['FunctionDefinitionExecutionArgs']:
        return pulumi.get(self, "execution")

    @execution.setter
    def execution(self, value: pulumi.Input['FunctionDefinitionExecutionArgs']):
        pulumi.set(self, "execution", value)


@pulumi.input_type
class FunctionDefinitionEnvironmentArgs:
    def __init__(__self__, *,
                 access_sysfs: Optional[pulumi.Input[bool]] = None,
                 execution: Optional[pulumi.Input['FunctionDefinitionExecutionArgs']] = None,
                 resource_access_policies: Optional[pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionResourceAccessPolicyArgs']]]] = None,
                 variables: Optional[Any] = None):
        if access_sysfs is not None:
            pulumi.set(__self__, "access_sysfs", access_sysfs)
        if execution is not None:
            pulumi.set(__self__, "execution", execution)
        if resource_access_policies is not None:
            pulumi.set(__self__, "resource_access_policies", resource_access_policies)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="accessSysfs")
    def access_sysfs(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "access_sysfs")

    @access_sysfs.setter
    def access_sysfs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "access_sysfs", value)

    @property
    @pulumi.getter
    def execution(self) -> Optional[pulumi.Input['FunctionDefinitionExecutionArgs']]:
        return pulumi.get(self, "execution")

    @execution.setter
    def execution(self, value: Optional[pulumi.Input['FunctionDefinitionExecutionArgs']]):
        pulumi.set(self, "execution", value)

    @property
    @pulumi.getter(name="resourceAccessPolicies")
    def resource_access_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionResourceAccessPolicyArgs']]]]:
        return pulumi.get(self, "resource_access_policies")

    @resource_access_policies.setter
    def resource_access_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionResourceAccessPolicyArgs']]]]):
        pulumi.set(self, "resource_access_policies", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[Any]:
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[Any]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class FunctionDefinitionExecutionArgs:
    def __init__(__self__, *,
                 isolation_mode: Optional[pulumi.Input[str]] = None,
                 run_as: Optional[pulumi.Input['FunctionDefinitionRunAsArgs']] = None):
        if isolation_mode is not None:
            pulumi.set(__self__, "isolation_mode", isolation_mode)
        if run_as is not None:
            pulumi.set(__self__, "run_as", run_as)

    @property
    @pulumi.getter(name="isolationMode")
    def isolation_mode(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "isolation_mode")

    @isolation_mode.setter
    def isolation_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolation_mode", value)

    @property
    @pulumi.getter(name="runAs")
    def run_as(self) -> Optional[pulumi.Input['FunctionDefinitionRunAsArgs']]:
        return pulumi.get(self, "run_as")

    @run_as.setter
    def run_as(self, value: Optional[pulumi.Input['FunctionDefinitionRunAsArgs']]):
        pulumi.set(self, "run_as", value)


@pulumi.input_type
class FunctionDefinitionFunctionConfigurationArgs:
    def __init__(__self__, *,
                 encoding_type: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input['FunctionDefinitionEnvironmentArgs']] = None,
                 exec_args: Optional[pulumi.Input[str]] = None,
                 executable: Optional[pulumi.Input[str]] = None,
                 memory_size: Optional[pulumi.Input[int]] = None,
                 pinned: Optional[pulumi.Input[bool]] = None,
                 timeout: Optional[pulumi.Input[int]] = None):
        if encoding_type is not None:
            pulumi.set(__self__, "encoding_type", encoding_type)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if exec_args is not None:
            pulumi.set(__self__, "exec_args", exec_args)
        if executable is not None:
            pulumi.set(__self__, "executable", executable)
        if memory_size is not None:
            pulumi.set(__self__, "memory_size", memory_size)
        if pinned is not None:
            pulumi.set(__self__, "pinned", pinned)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="encodingType")
    def encoding_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "encoding_type")

    @encoding_type.setter
    def encoding_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encoding_type", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['FunctionDefinitionEnvironmentArgs']]:
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['FunctionDefinitionEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="execArgs")
    def exec_args(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "exec_args")

    @exec_args.setter
    def exec_args(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exec_args", value)

    @property
    @pulumi.getter
    def executable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "executable")

    @executable.setter
    def executable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "executable", value)

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "memory_size")

    @memory_size.setter
    def memory_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory_size", value)

    @property
    @pulumi.getter
    def pinned(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "pinned")

    @pinned.setter
    def pinned(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "pinned", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class FunctionDefinitionFunctionDefinitionVersionArgs:
    def __init__(__self__, *,
                 functions: pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionFunctionArgs']]],
                 default_config: Optional[pulumi.Input['FunctionDefinitionDefaultConfigArgs']] = None):
        pulumi.set(__self__, "functions", functions)
        if default_config is not None:
            pulumi.set(__self__, "default_config", default_config)

    @property
    @pulumi.getter
    def functions(self) -> pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionFunctionArgs']]]:
        return pulumi.get(self, "functions")

    @functions.setter
    def functions(self, value: pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionFunctionArgs']]]):
        pulumi.set(self, "functions", value)

    @property
    @pulumi.getter(name="defaultConfig")
    def default_config(self) -> Optional[pulumi.Input['FunctionDefinitionDefaultConfigArgs']]:
        return pulumi.get(self, "default_config")

    @default_config.setter
    def default_config(self, value: Optional[pulumi.Input['FunctionDefinitionDefaultConfigArgs']]):
        pulumi.set(self, "default_config", value)


@pulumi.input_type
class FunctionDefinitionFunctionArgs:
    def __init__(__self__, *,
                 function_arn: pulumi.Input[str],
                 function_configuration: pulumi.Input['FunctionDefinitionFunctionConfigurationArgs'],
                 id: pulumi.Input[str]):
        pulumi.set(__self__, "function_arn", function_arn)
        pulumi.set(__self__, "function_configuration", function_configuration)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "function_arn")

    @function_arn.setter
    def function_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "function_arn", value)

    @property
    @pulumi.getter(name="functionConfiguration")
    def function_configuration(self) -> pulumi.Input['FunctionDefinitionFunctionConfigurationArgs']:
        return pulumi.get(self, "function_configuration")

    @function_configuration.setter
    def function_configuration(self, value: pulumi.Input['FunctionDefinitionFunctionConfigurationArgs']):
        pulumi.set(self, "function_configuration", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)


@pulumi.input_type
class FunctionDefinitionResourceAccessPolicyArgs:
    def __init__(__self__, *,
                 resource_id: pulumi.Input[str],
                 permission: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "resource_id", resource_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "permission", value)


@pulumi.input_type
class FunctionDefinitionRunAsArgs:
    def __init__(__self__, *,
                 gid: Optional[pulumi.Input[int]] = None,
                 uid: Optional[pulumi.Input[int]] = None):
        if gid is not None:
            pulumi.set(__self__, "gid", gid)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter
    def gid(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "gid")

    @gid.setter
    def gid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gid", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uid", value)


@pulumi.input_type
class FunctionDefinitionVersionDefaultConfigArgs:
    def __init__(__self__, *,
                 execution: pulumi.Input['FunctionDefinitionVersionExecutionArgs']):
        pulumi.set(__self__, "execution", execution)

    @property
    @pulumi.getter
    def execution(self) -> pulumi.Input['FunctionDefinitionVersionExecutionArgs']:
        return pulumi.get(self, "execution")

    @execution.setter
    def execution(self, value: pulumi.Input['FunctionDefinitionVersionExecutionArgs']):
        pulumi.set(self, "execution", value)


@pulumi.input_type
class FunctionDefinitionVersionEnvironmentArgs:
    def __init__(__self__, *,
                 access_sysfs: Optional[pulumi.Input[bool]] = None,
                 execution: Optional[pulumi.Input['FunctionDefinitionVersionExecutionArgs']] = None,
                 resource_access_policies: Optional[pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionVersionResourceAccessPolicyArgs']]]] = None,
                 variables: Optional[Any] = None):
        if access_sysfs is not None:
            pulumi.set(__self__, "access_sysfs", access_sysfs)
        if execution is not None:
            pulumi.set(__self__, "execution", execution)
        if resource_access_policies is not None:
            pulumi.set(__self__, "resource_access_policies", resource_access_policies)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="accessSysfs")
    def access_sysfs(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "access_sysfs")

    @access_sysfs.setter
    def access_sysfs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "access_sysfs", value)

    @property
    @pulumi.getter
    def execution(self) -> Optional[pulumi.Input['FunctionDefinitionVersionExecutionArgs']]:
        return pulumi.get(self, "execution")

    @execution.setter
    def execution(self, value: Optional[pulumi.Input['FunctionDefinitionVersionExecutionArgs']]):
        pulumi.set(self, "execution", value)

    @property
    @pulumi.getter(name="resourceAccessPolicies")
    def resource_access_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionVersionResourceAccessPolicyArgs']]]]:
        return pulumi.get(self, "resource_access_policies")

    @resource_access_policies.setter
    def resource_access_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FunctionDefinitionVersionResourceAccessPolicyArgs']]]]):
        pulumi.set(self, "resource_access_policies", value)

    @property
    @pulumi.getter
    def variables(self) -> Optional[Any]:
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[Any]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class FunctionDefinitionVersionExecutionArgs:
    def __init__(__self__, *,
                 isolation_mode: Optional[pulumi.Input[str]] = None,
                 run_as: Optional[pulumi.Input['FunctionDefinitionVersionRunAsArgs']] = None):
        if isolation_mode is not None:
            pulumi.set(__self__, "isolation_mode", isolation_mode)
        if run_as is not None:
            pulumi.set(__self__, "run_as", run_as)

    @property
    @pulumi.getter(name="isolationMode")
    def isolation_mode(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "isolation_mode")

    @isolation_mode.setter
    def isolation_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isolation_mode", value)

    @property
    @pulumi.getter(name="runAs")
    def run_as(self) -> Optional[pulumi.Input['FunctionDefinitionVersionRunAsArgs']]:
        return pulumi.get(self, "run_as")

    @run_as.setter
    def run_as(self, value: Optional[pulumi.Input['FunctionDefinitionVersionRunAsArgs']]):
        pulumi.set(self, "run_as", value)


@pulumi.input_type
class FunctionDefinitionVersionFunctionConfigurationArgs:
    def __init__(__self__, *,
                 encoding_type: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input['FunctionDefinitionVersionEnvironmentArgs']] = None,
                 exec_args: Optional[pulumi.Input[str]] = None,
                 executable: Optional[pulumi.Input[str]] = None,
                 memory_size: Optional[pulumi.Input[int]] = None,
                 pinned: Optional[pulumi.Input[bool]] = None,
                 timeout: Optional[pulumi.Input[int]] = None):
        if encoding_type is not None:
            pulumi.set(__self__, "encoding_type", encoding_type)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if exec_args is not None:
            pulumi.set(__self__, "exec_args", exec_args)
        if executable is not None:
            pulumi.set(__self__, "executable", executable)
        if memory_size is not None:
            pulumi.set(__self__, "memory_size", memory_size)
        if pinned is not None:
            pulumi.set(__self__, "pinned", pinned)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="encodingType")
    def encoding_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "encoding_type")

    @encoding_type.setter
    def encoding_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encoding_type", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['FunctionDefinitionVersionEnvironmentArgs']]:
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['FunctionDefinitionVersionEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="execArgs")
    def exec_args(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "exec_args")

    @exec_args.setter
    def exec_args(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exec_args", value)

    @property
    @pulumi.getter
    def executable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "executable")

    @executable.setter
    def executable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "executable", value)

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "memory_size")

    @memory_size.setter
    def memory_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory_size", value)

    @property
    @pulumi.getter
    def pinned(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "pinned")

    @pinned.setter
    def pinned(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "pinned", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class FunctionDefinitionVersionFunctionArgs:
    def __init__(__self__, *,
                 function_arn: pulumi.Input[str],
                 function_configuration: pulumi.Input['FunctionDefinitionVersionFunctionConfigurationArgs'],
                 id: pulumi.Input[str]):
        pulumi.set(__self__, "function_arn", function_arn)
        pulumi.set(__self__, "function_configuration", function_configuration)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "function_arn")

    @function_arn.setter
    def function_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "function_arn", value)

    @property
    @pulumi.getter(name="functionConfiguration")
    def function_configuration(self) -> pulumi.Input['FunctionDefinitionVersionFunctionConfigurationArgs']:
        return pulumi.get(self, "function_configuration")

    @function_configuration.setter
    def function_configuration(self, value: pulumi.Input['FunctionDefinitionVersionFunctionConfigurationArgs']):
        pulumi.set(self, "function_configuration", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)


@pulumi.input_type
class FunctionDefinitionVersionResourceAccessPolicyArgs:
    def __init__(__self__, *,
                 resource_id: pulumi.Input[str],
                 permission: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "resource_id", resource_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "permission", value)


@pulumi.input_type
class FunctionDefinitionVersionRunAsArgs:
    def __init__(__self__, *,
                 gid: Optional[pulumi.Input[int]] = None,
                 uid: Optional[pulumi.Input[int]] = None):
        if gid is not None:
            pulumi.set(__self__, "gid", gid)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter
    def gid(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "gid")

    @gid.setter
    def gid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "gid", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "uid", value)


@pulumi.input_type
class GroupGroupVersionArgs:
    def __init__(__self__, *,
                 connector_definition_version_arn: Optional[pulumi.Input[str]] = None,
                 core_definition_version_arn: Optional[pulumi.Input[str]] = None,
                 device_definition_version_arn: Optional[pulumi.Input[str]] = None,
                 function_definition_version_arn: Optional[pulumi.Input[str]] = None,
                 logger_definition_version_arn: Optional[pulumi.Input[str]] = None,
                 resource_definition_version_arn: Optional[pulumi.Input[str]] = None,
                 subscription_definition_version_arn: Optional[pulumi.Input[str]] = None):
        if connector_definition_version_arn is not None:
            pulumi.set(__self__, "connector_definition_version_arn", connector_definition_version_arn)
        if core_definition_version_arn is not None:
            pulumi.set(__self__, "core_definition_version_arn", core_definition_version_arn)
        if device_definition_version_arn is not None:
            pulumi.set(__self__, "device_definition_version_arn", device_definition_version_arn)
        if function_definition_version_arn is not None:
            pulumi.set(__self__, "function_definition_version_arn", function_definition_version_arn)
        if logger_definition_version_arn is not None:
            pulumi.set(__self__, "logger_definition_version_arn", logger_definition_version_arn)
        if resource_definition_version_arn is not None:
            pulumi.set(__self__, "resource_definition_version_arn", resource_definition_version_arn)
        if subscription_definition_version_arn is not None:
            pulumi.set(__self__, "subscription_definition_version_arn", subscription_definition_version_arn)

    @property
    @pulumi.getter(name="connectorDefinitionVersionArn")
    def connector_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "connector_definition_version_arn")

    @connector_definition_version_arn.setter
    def connector_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connector_definition_version_arn", value)

    @property
    @pulumi.getter(name="coreDefinitionVersionArn")
    def core_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "core_definition_version_arn")

    @core_definition_version_arn.setter
    def core_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "core_definition_version_arn", value)

    @property
    @pulumi.getter(name="deviceDefinitionVersionArn")
    def device_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "device_definition_version_arn")

    @device_definition_version_arn.setter
    def device_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "device_definition_version_arn", value)

    @property
    @pulumi.getter(name="functionDefinitionVersionArn")
    def function_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "function_definition_version_arn")

    @function_definition_version_arn.setter
    def function_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function_definition_version_arn", value)

    @property
    @pulumi.getter(name="loggerDefinitionVersionArn")
    def logger_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "logger_definition_version_arn")

    @logger_definition_version_arn.setter
    def logger_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logger_definition_version_arn", value)

    @property
    @pulumi.getter(name="resourceDefinitionVersionArn")
    def resource_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "resource_definition_version_arn")

    @resource_definition_version_arn.setter
    def resource_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_definition_version_arn", value)

    @property
    @pulumi.getter(name="subscriptionDefinitionVersionArn")
    def subscription_definition_version_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "subscription_definition_version_arn")

    @subscription_definition_version_arn.setter
    def subscription_definition_version_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subscription_definition_version_arn", value)


@pulumi.input_type
class LoggerDefinitionLoggerDefinitionVersionArgs:
    def __init__(__self__, *,
                 loggers: pulumi.Input[Sequence[pulumi.Input['LoggerDefinitionLoggerArgs']]]):
        pulumi.set(__self__, "loggers", loggers)

    @property
    @pulumi.getter
    def loggers(self) -> pulumi.Input[Sequence[pulumi.Input['LoggerDefinitionLoggerArgs']]]:
        return pulumi.get(self, "loggers")

    @loggers.setter
    def loggers(self, value: pulumi.Input[Sequence[pulumi.Input['LoggerDefinitionLoggerArgs']]]):
        pulumi.set(self, "loggers", value)


@pulumi.input_type
class LoggerDefinitionLoggerArgs:
    def __init__(__self__, *,
                 component: pulumi.Input[str],
                 id: pulumi.Input[str],
                 level: pulumi.Input[str],
                 type: pulumi.Input[str],
                 space: Optional[pulumi.Input[int]] = None):
        pulumi.set(__self__, "component", component)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "level", level)
        pulumi.set(__self__, "type", type)
        if space is not None:
            pulumi.set(__self__, "space", space)

    @property
    @pulumi.getter
    def component(self) -> pulumi.Input[str]:
        return pulumi.get(self, "component")

    @component.setter
    def component(self, value: pulumi.Input[str]):
        pulumi.set(self, "component", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def level(self) -> pulumi.Input[str]:
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: pulumi.Input[str]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def space(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "space")

    @space.setter
    def space(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "space", value)


@pulumi.input_type
class LoggerDefinitionVersionLoggerArgs:
    def __init__(__self__, *,
                 component: pulumi.Input[str],
                 id: pulumi.Input[str],
                 level: pulumi.Input[str],
                 type: pulumi.Input[str],
                 space: Optional[pulumi.Input[int]] = None):
        pulumi.set(__self__, "component", component)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "level", level)
        pulumi.set(__self__, "type", type)
        if space is not None:
            pulumi.set(__self__, "space", space)

    @property
    @pulumi.getter
    def component(self) -> pulumi.Input[str]:
        return pulumi.get(self, "component")

    @component.setter
    def component(self, value: pulumi.Input[str]):
        pulumi.set(self, "component", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def level(self) -> pulumi.Input[str]:
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: pulumi.Input[str]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def space(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "space")

    @space.setter
    def space(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "space", value)


@pulumi.input_type
class ResourceDefinitionGroupOwnerSettingArgs:
    def __init__(__self__, *,
                 auto_add_group_owner: pulumi.Input[bool],
                 group_owner: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "auto_add_group_owner", auto_add_group_owner)
        if group_owner is not None:
            pulumi.set(__self__, "group_owner", group_owner)

    @property
    @pulumi.getter(name="autoAddGroupOwner")
    def auto_add_group_owner(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "auto_add_group_owner")

    @auto_add_group_owner.setter
    def auto_add_group_owner(self, value: pulumi.Input[bool]):
        pulumi.set(self, "auto_add_group_owner", value)

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "group_owner")

    @group_owner.setter
    def group_owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_owner", value)


@pulumi.input_type
class ResourceDefinitionLocalDeviceResourceDataArgs:
    def __init__(__self__, *,
                 source_path: pulumi.Input[str],
                 group_owner_setting: Optional[pulumi.Input['ResourceDefinitionGroupOwnerSettingArgs']] = None):
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source_path")

    @source_path.setter
    def source_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_path", value)

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionGroupOwnerSettingArgs']]:
        return pulumi.get(self, "group_owner_setting")

    @group_owner_setting.setter
    def group_owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionGroupOwnerSettingArgs']]):
        pulumi.set(self, "group_owner_setting", value)


@pulumi.input_type
class ResourceDefinitionLocalVolumeResourceDataArgs:
    def __init__(__self__, *,
                 destination_path: pulumi.Input[str],
                 source_path: pulumi.Input[str],
                 group_owner_setting: Optional[pulumi.Input['ResourceDefinitionGroupOwnerSettingArgs']] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination_path")

    @destination_path.setter
    def destination_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_path", value)

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source_path")

    @source_path.setter
    def source_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_path", value)

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionGroupOwnerSettingArgs']]:
        return pulumi.get(self, "group_owner_setting")

    @group_owner_setting.setter
    def group_owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionGroupOwnerSettingArgs']]):
        pulumi.set(self, "group_owner_setting", value)


@pulumi.input_type
class ResourceDefinitionResourceDataContainerArgs:
    def __init__(__self__, *,
                 local_device_resource_data: Optional[pulumi.Input['ResourceDefinitionLocalDeviceResourceDataArgs']] = None,
                 local_volume_resource_data: Optional[pulumi.Input['ResourceDefinitionLocalVolumeResourceDataArgs']] = None,
                 s3_machine_learning_model_resource_data: Optional[pulumi.Input['ResourceDefinitionS3MachineLearningModelResourceDataArgs']] = None,
                 sage_maker_machine_learning_model_resource_data: Optional[pulumi.Input['ResourceDefinitionSageMakerMachineLearningModelResourceDataArgs']] = None,
                 secrets_manager_secret_resource_data: Optional[pulumi.Input['ResourceDefinitionSecretsManagerSecretResourceDataArgs']] = None):
        if local_device_resource_data is not None:
            pulumi.set(__self__, "local_device_resource_data", local_device_resource_data)
        if local_volume_resource_data is not None:
            pulumi.set(__self__, "local_volume_resource_data", local_volume_resource_data)
        if s3_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "s3_machine_learning_model_resource_data", s3_machine_learning_model_resource_data)
        if sage_maker_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "sage_maker_machine_learning_model_resource_data", sage_maker_machine_learning_model_resource_data)
        if secrets_manager_secret_resource_data is not None:
            pulumi.set(__self__, "secrets_manager_secret_resource_data", secrets_manager_secret_resource_data)

    @property
    @pulumi.getter(name="localDeviceResourceData")
    def local_device_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionLocalDeviceResourceDataArgs']]:
        return pulumi.get(self, "local_device_resource_data")

    @local_device_resource_data.setter
    def local_device_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionLocalDeviceResourceDataArgs']]):
        pulumi.set(self, "local_device_resource_data", value)

    @property
    @pulumi.getter(name="localVolumeResourceData")
    def local_volume_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionLocalVolumeResourceDataArgs']]:
        return pulumi.get(self, "local_volume_resource_data")

    @local_volume_resource_data.setter
    def local_volume_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionLocalVolumeResourceDataArgs']]):
        pulumi.set(self, "local_volume_resource_data", value)

    @property
    @pulumi.getter(name="s3MachineLearningModelResourceData")
    def s3_machine_learning_model_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionS3MachineLearningModelResourceDataArgs']]:
        return pulumi.get(self, "s3_machine_learning_model_resource_data")

    @s3_machine_learning_model_resource_data.setter
    def s3_machine_learning_model_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionS3MachineLearningModelResourceDataArgs']]):
        pulumi.set(self, "s3_machine_learning_model_resource_data", value)

    @property
    @pulumi.getter(name="sageMakerMachineLearningModelResourceData")
    def sage_maker_machine_learning_model_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionSageMakerMachineLearningModelResourceDataArgs']]:
        return pulumi.get(self, "sage_maker_machine_learning_model_resource_data")

    @sage_maker_machine_learning_model_resource_data.setter
    def sage_maker_machine_learning_model_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionSageMakerMachineLearningModelResourceDataArgs']]):
        pulumi.set(self, "sage_maker_machine_learning_model_resource_data", value)

    @property
    @pulumi.getter(name="secretsManagerSecretResourceData")
    def secrets_manager_secret_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionSecretsManagerSecretResourceDataArgs']]:
        return pulumi.get(self, "secrets_manager_secret_resource_data")

    @secrets_manager_secret_resource_data.setter
    def secrets_manager_secret_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionSecretsManagerSecretResourceDataArgs']]):
        pulumi.set(self, "secrets_manager_secret_resource_data", value)


@pulumi.input_type
class ResourceDefinitionResourceDefinitionVersionArgs:
    def __init__(__self__, *,
                 resources: pulumi.Input[Sequence[pulumi.Input['ResourceDefinitionResourceInstanceArgs']]]):
        pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Input[Sequence[pulumi.Input['ResourceDefinitionResourceInstanceArgs']]]:
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: pulumi.Input[Sequence[pulumi.Input['ResourceDefinitionResourceInstanceArgs']]]):
        pulumi.set(self, "resources", value)


@pulumi.input_type
class ResourceDefinitionResourceDownloadOwnerSettingArgs:
    def __init__(__self__, *,
                 group_owner: pulumi.Input[str],
                 group_permission: pulumi.Input[str]):
        pulumi.set(__self__, "group_owner", group_owner)
        pulumi.set(__self__, "group_permission", group_permission)

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> pulumi.Input[str]:
        return pulumi.get(self, "group_owner")

    @group_owner.setter
    def group_owner(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_owner", value)

    @property
    @pulumi.getter(name="groupPermission")
    def group_permission(self) -> pulumi.Input[str]:
        return pulumi.get(self, "group_permission")

    @group_permission.setter
    def group_permission(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_permission", value)


@pulumi.input_type
class ResourceDefinitionResourceInstanceArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 name: pulumi.Input[str],
                 resource_data_container: pulumi.Input['ResourceDefinitionResourceDataContainerArgs']):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "resource_data_container", resource_data_container)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceDataContainer")
    def resource_data_container(self) -> pulumi.Input['ResourceDefinitionResourceDataContainerArgs']:
        return pulumi.get(self, "resource_data_container")

    @resource_data_container.setter
    def resource_data_container(self, value: pulumi.Input['ResourceDefinitionResourceDataContainerArgs']):
        pulumi.set(self, "resource_data_container", value)


@pulumi.input_type
class ResourceDefinitionS3MachineLearningModelResourceDataArgs:
    def __init__(__self__, *,
                 destination_path: pulumi.Input[str],
                 s3_uri: pulumi.Input[str],
                 owner_setting: Optional[pulumi.Input['ResourceDefinitionResourceDownloadOwnerSettingArgs']] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "s3_uri", s3_uri)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination_path")

    @destination_path.setter
    def destination_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_path", value)

    @property
    @pulumi.getter(name="s3Uri")
    def s3_uri(self) -> pulumi.Input[str]:
        return pulumi.get(self, "s3_uri")

    @s3_uri.setter
    def s3_uri(self, value: pulumi.Input[str]):
        pulumi.set(self, "s3_uri", value)

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionResourceDownloadOwnerSettingArgs']]:
        return pulumi.get(self, "owner_setting")

    @owner_setting.setter
    def owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionResourceDownloadOwnerSettingArgs']]):
        pulumi.set(self, "owner_setting", value)


@pulumi.input_type
class ResourceDefinitionSageMakerMachineLearningModelResourceDataArgs:
    def __init__(__self__, *,
                 destination_path: pulumi.Input[str],
                 sage_maker_job_arn: pulumi.Input[str],
                 owner_setting: Optional[pulumi.Input['ResourceDefinitionResourceDownloadOwnerSettingArgs']] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "sage_maker_job_arn", sage_maker_job_arn)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination_path")

    @destination_path.setter
    def destination_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_path", value)

    @property
    @pulumi.getter(name="sageMakerJobArn")
    def sage_maker_job_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "sage_maker_job_arn")

    @sage_maker_job_arn.setter
    def sage_maker_job_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "sage_maker_job_arn", value)

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionResourceDownloadOwnerSettingArgs']]:
        return pulumi.get(self, "owner_setting")

    @owner_setting.setter
    def owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionResourceDownloadOwnerSettingArgs']]):
        pulumi.set(self, "owner_setting", value)


@pulumi.input_type
class ResourceDefinitionSecretsManagerSecretResourceDataArgs:
    def __init__(__self__, *,
                 a_rn: pulumi.Input[str],
                 additional_staging_labels_to_download: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "a_rn", a_rn)
        if additional_staging_labels_to_download is not None:
            pulumi.set(__self__, "additional_staging_labels_to_download", additional_staging_labels_to_download)

    @property
    @pulumi.getter(name="aRN")
    def a_rn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "a_rn")

    @a_rn.setter
    def a_rn(self, value: pulumi.Input[str]):
        pulumi.set(self, "a_rn", value)

    @property
    @pulumi.getter(name="additionalStagingLabelsToDownload")
    def additional_staging_labels_to_download(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "additional_staging_labels_to_download")

    @additional_staging_labels_to_download.setter
    def additional_staging_labels_to_download(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_staging_labels_to_download", value)


@pulumi.input_type
class ResourceDefinitionVersionGroupOwnerSettingArgs:
    def __init__(__self__, *,
                 auto_add_group_owner: pulumi.Input[bool],
                 group_owner: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "auto_add_group_owner", auto_add_group_owner)
        if group_owner is not None:
            pulumi.set(__self__, "group_owner", group_owner)

    @property
    @pulumi.getter(name="autoAddGroupOwner")
    def auto_add_group_owner(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "auto_add_group_owner")

    @auto_add_group_owner.setter
    def auto_add_group_owner(self, value: pulumi.Input[bool]):
        pulumi.set(self, "auto_add_group_owner", value)

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "group_owner")

    @group_owner.setter
    def group_owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_owner", value)


@pulumi.input_type
class ResourceDefinitionVersionLocalDeviceResourceDataArgs:
    def __init__(__self__, *,
                 source_path: pulumi.Input[str],
                 group_owner_setting: Optional[pulumi.Input['ResourceDefinitionVersionGroupOwnerSettingArgs']] = None):
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source_path")

    @source_path.setter
    def source_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_path", value)

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionVersionGroupOwnerSettingArgs']]:
        return pulumi.get(self, "group_owner_setting")

    @group_owner_setting.setter
    def group_owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionVersionGroupOwnerSettingArgs']]):
        pulumi.set(self, "group_owner_setting", value)


@pulumi.input_type
class ResourceDefinitionVersionLocalVolumeResourceDataArgs:
    def __init__(__self__, *,
                 destination_path: pulumi.Input[str],
                 source_path: pulumi.Input[str],
                 group_owner_setting: Optional[pulumi.Input['ResourceDefinitionVersionGroupOwnerSettingArgs']] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination_path")

    @destination_path.setter
    def destination_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_path", value)

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source_path")

    @source_path.setter
    def source_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_path", value)

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionVersionGroupOwnerSettingArgs']]:
        return pulumi.get(self, "group_owner_setting")

    @group_owner_setting.setter
    def group_owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionVersionGroupOwnerSettingArgs']]):
        pulumi.set(self, "group_owner_setting", value)


@pulumi.input_type
class ResourceDefinitionVersionResourceDataContainerArgs:
    def __init__(__self__, *,
                 local_device_resource_data: Optional[pulumi.Input['ResourceDefinitionVersionLocalDeviceResourceDataArgs']] = None,
                 local_volume_resource_data: Optional[pulumi.Input['ResourceDefinitionVersionLocalVolumeResourceDataArgs']] = None,
                 s3_machine_learning_model_resource_data: Optional[pulumi.Input['ResourceDefinitionVersionS3MachineLearningModelResourceDataArgs']] = None,
                 sage_maker_machine_learning_model_resource_data: Optional[pulumi.Input['ResourceDefinitionVersionSageMakerMachineLearningModelResourceDataArgs']] = None,
                 secrets_manager_secret_resource_data: Optional[pulumi.Input['ResourceDefinitionVersionSecretsManagerSecretResourceDataArgs']] = None):
        if local_device_resource_data is not None:
            pulumi.set(__self__, "local_device_resource_data", local_device_resource_data)
        if local_volume_resource_data is not None:
            pulumi.set(__self__, "local_volume_resource_data", local_volume_resource_data)
        if s3_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "s3_machine_learning_model_resource_data", s3_machine_learning_model_resource_data)
        if sage_maker_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "sage_maker_machine_learning_model_resource_data", sage_maker_machine_learning_model_resource_data)
        if secrets_manager_secret_resource_data is not None:
            pulumi.set(__self__, "secrets_manager_secret_resource_data", secrets_manager_secret_resource_data)

    @property
    @pulumi.getter(name="localDeviceResourceData")
    def local_device_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionVersionLocalDeviceResourceDataArgs']]:
        return pulumi.get(self, "local_device_resource_data")

    @local_device_resource_data.setter
    def local_device_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionVersionLocalDeviceResourceDataArgs']]):
        pulumi.set(self, "local_device_resource_data", value)

    @property
    @pulumi.getter(name="localVolumeResourceData")
    def local_volume_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionVersionLocalVolumeResourceDataArgs']]:
        return pulumi.get(self, "local_volume_resource_data")

    @local_volume_resource_data.setter
    def local_volume_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionVersionLocalVolumeResourceDataArgs']]):
        pulumi.set(self, "local_volume_resource_data", value)

    @property
    @pulumi.getter(name="s3MachineLearningModelResourceData")
    def s3_machine_learning_model_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionVersionS3MachineLearningModelResourceDataArgs']]:
        return pulumi.get(self, "s3_machine_learning_model_resource_data")

    @s3_machine_learning_model_resource_data.setter
    def s3_machine_learning_model_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionVersionS3MachineLearningModelResourceDataArgs']]):
        pulumi.set(self, "s3_machine_learning_model_resource_data", value)

    @property
    @pulumi.getter(name="sageMakerMachineLearningModelResourceData")
    def sage_maker_machine_learning_model_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionVersionSageMakerMachineLearningModelResourceDataArgs']]:
        return pulumi.get(self, "sage_maker_machine_learning_model_resource_data")

    @sage_maker_machine_learning_model_resource_data.setter
    def sage_maker_machine_learning_model_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionVersionSageMakerMachineLearningModelResourceDataArgs']]):
        pulumi.set(self, "sage_maker_machine_learning_model_resource_data", value)

    @property
    @pulumi.getter(name="secretsManagerSecretResourceData")
    def secrets_manager_secret_resource_data(self) -> Optional[pulumi.Input['ResourceDefinitionVersionSecretsManagerSecretResourceDataArgs']]:
        return pulumi.get(self, "secrets_manager_secret_resource_data")

    @secrets_manager_secret_resource_data.setter
    def secrets_manager_secret_resource_data(self, value: Optional[pulumi.Input['ResourceDefinitionVersionSecretsManagerSecretResourceDataArgs']]):
        pulumi.set(self, "secrets_manager_secret_resource_data", value)


@pulumi.input_type
class ResourceDefinitionVersionResourceDownloadOwnerSettingArgs:
    def __init__(__self__, *,
                 group_owner: pulumi.Input[str],
                 group_permission: pulumi.Input[str]):
        pulumi.set(__self__, "group_owner", group_owner)
        pulumi.set(__self__, "group_permission", group_permission)

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> pulumi.Input[str]:
        return pulumi.get(self, "group_owner")

    @group_owner.setter
    def group_owner(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_owner", value)

    @property
    @pulumi.getter(name="groupPermission")
    def group_permission(self) -> pulumi.Input[str]:
        return pulumi.get(self, "group_permission")

    @group_permission.setter
    def group_permission(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_permission", value)


@pulumi.input_type
class ResourceDefinitionVersionResourceInstanceArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 name: pulumi.Input[str],
                 resource_data_container: pulumi.Input['ResourceDefinitionVersionResourceDataContainerArgs']):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "resource_data_container", resource_data_container)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceDataContainer")
    def resource_data_container(self) -> pulumi.Input['ResourceDefinitionVersionResourceDataContainerArgs']:
        return pulumi.get(self, "resource_data_container")

    @resource_data_container.setter
    def resource_data_container(self, value: pulumi.Input['ResourceDefinitionVersionResourceDataContainerArgs']):
        pulumi.set(self, "resource_data_container", value)


@pulumi.input_type
class ResourceDefinitionVersionS3MachineLearningModelResourceDataArgs:
    def __init__(__self__, *,
                 destination_path: pulumi.Input[str],
                 s3_uri: pulumi.Input[str],
                 owner_setting: Optional[pulumi.Input['ResourceDefinitionVersionResourceDownloadOwnerSettingArgs']] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "s3_uri", s3_uri)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination_path")

    @destination_path.setter
    def destination_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_path", value)

    @property
    @pulumi.getter(name="s3Uri")
    def s3_uri(self) -> pulumi.Input[str]:
        return pulumi.get(self, "s3_uri")

    @s3_uri.setter
    def s3_uri(self, value: pulumi.Input[str]):
        pulumi.set(self, "s3_uri", value)

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionVersionResourceDownloadOwnerSettingArgs']]:
        return pulumi.get(self, "owner_setting")

    @owner_setting.setter
    def owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionVersionResourceDownloadOwnerSettingArgs']]):
        pulumi.set(self, "owner_setting", value)


@pulumi.input_type
class ResourceDefinitionVersionSageMakerMachineLearningModelResourceDataArgs:
    def __init__(__self__, *,
                 destination_path: pulumi.Input[str],
                 sage_maker_job_arn: pulumi.Input[str],
                 owner_setting: Optional[pulumi.Input['ResourceDefinitionVersionResourceDownloadOwnerSettingArgs']] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "sage_maker_job_arn", sage_maker_job_arn)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> pulumi.Input[str]:
        return pulumi.get(self, "destination_path")

    @destination_path.setter
    def destination_path(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_path", value)

    @property
    @pulumi.getter(name="sageMakerJobArn")
    def sage_maker_job_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "sage_maker_job_arn")

    @sage_maker_job_arn.setter
    def sage_maker_job_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "sage_maker_job_arn", value)

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional[pulumi.Input['ResourceDefinitionVersionResourceDownloadOwnerSettingArgs']]:
        return pulumi.get(self, "owner_setting")

    @owner_setting.setter
    def owner_setting(self, value: Optional[pulumi.Input['ResourceDefinitionVersionResourceDownloadOwnerSettingArgs']]):
        pulumi.set(self, "owner_setting", value)


@pulumi.input_type
class ResourceDefinitionVersionSecretsManagerSecretResourceDataArgs:
    def __init__(__self__, *,
                 a_rn: pulumi.Input[str],
                 additional_staging_labels_to_download: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "a_rn", a_rn)
        if additional_staging_labels_to_download is not None:
            pulumi.set(__self__, "additional_staging_labels_to_download", additional_staging_labels_to_download)

    @property
    @pulumi.getter(name="aRN")
    def a_rn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "a_rn")

    @a_rn.setter
    def a_rn(self, value: pulumi.Input[str]):
        pulumi.set(self, "a_rn", value)

    @property
    @pulumi.getter(name="additionalStagingLabelsToDownload")
    def additional_staging_labels_to_download(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "additional_staging_labels_to_download")

    @additional_staging_labels_to_download.setter
    def additional_staging_labels_to_download(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_staging_labels_to_download", value)


@pulumi.input_type
class SubscriptionDefinitionSubscriptionDefinitionVersionArgs:
    def __init__(__self__, *,
                 subscriptions: pulumi.Input[Sequence[pulumi.Input['SubscriptionDefinitionSubscriptionArgs']]]):
        pulumi.set(__self__, "subscriptions", subscriptions)

    @property
    @pulumi.getter
    def subscriptions(self) -> pulumi.Input[Sequence[pulumi.Input['SubscriptionDefinitionSubscriptionArgs']]]:
        return pulumi.get(self, "subscriptions")

    @subscriptions.setter
    def subscriptions(self, value: pulumi.Input[Sequence[pulumi.Input['SubscriptionDefinitionSubscriptionArgs']]]):
        pulumi.set(self, "subscriptions", value)


@pulumi.input_type
class SubscriptionDefinitionSubscriptionArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 source: pulumi.Input[str],
                 subject: pulumi.Input[str],
                 target: pulumi.Input[str]):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "subject", subject)
        pulumi.set(__self__, "target", target)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def source(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input[str]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter
    def subject(self) -> pulumi.Input[str]:
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: pulumi.Input[str]):
        pulumi.set(self, "subject", value)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[str]:
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[str]):
        pulumi.set(self, "target", value)


@pulumi.input_type
class SubscriptionDefinitionVersionSubscriptionArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 source: pulumi.Input[str],
                 subject: pulumi.Input[str],
                 target: pulumi.Input[str]):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "subject", subject)
        pulumi.set(__self__, "target", target)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def source(self) -> pulumi.Input[str]:
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input[str]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter
    def subject(self) -> pulumi.Input[str]:
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: pulumi.Input[str]):
        pulumi.set(self, "subject", value)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[str]:
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[str]):
        pulumi.set(self, "target", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'AssessmentAWSAccount',
    'AssessmentAWSService',
    'AssessmentAssessmentReportsDestination',
    'AssessmentDelegation',
    'AssessmentRole',
    'AssessmentScope',
    'AssessmentTag',
]

@pulumi.output_type
class AssessmentAWSAccount(dict):
    """
    The AWS account associated with the assessment.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "emailAddress":
            suggest = "email_address"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AssessmentAWSAccount. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AssessmentAWSAccount.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AssessmentAWSAccount.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 email_address: Optional[str] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None):
        """
        The AWS account associated with the assessment.
        """
        if email_address is not None:
            pulumi.set(__self__, "email_address", email_address)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="emailAddress")
    def email_address(self) -> Optional[str]:
        return pulumi.get(self, "email_address")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")


@pulumi.output_type
class AssessmentAWSService(dict):
    """
    An AWS service such as Amazon S3, AWS CloudTrail, and so on.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "serviceName":
            suggest = "service_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AssessmentAWSService. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AssessmentAWSService.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AssessmentAWSService.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 service_name: Optional[str] = None):
        """
        An AWS service such as Amazon S3, AWS CloudTrail, and so on.
        """
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[str]:
        return pulumi.get(self, "service_name")


@pulumi.output_type
class AssessmentAssessmentReportsDestination(dict):
    """
    The destination in which evidence reports are stored for the specified assessment.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationType":
            suggest = "destination_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AssessmentAssessmentReportsDestination. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AssessmentAssessmentReportsDestination.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AssessmentAssessmentReportsDestination.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination: Optional[str] = None,
                 destination_type: Optional['AssessmentAssessmentReportDestinationType'] = None):
        """
        The destination in which evidence reports are stored for the specified assessment.
        """
        if destination is not None:
            pulumi.set(__self__, "destination", destination)
        if destination_type is not None:
            pulumi.set(__self__, "destination_type", destination_type)

    @property
    @pulumi.getter
    def destination(self) -> Optional[str]:
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter(name="destinationType")
    def destination_type(self) -> Optional['AssessmentAssessmentReportDestinationType']:
        return pulumi.get(self, "destination_type")


@pulumi.output_type
class AssessmentDelegation(dict):
    """
    The assignment of a control set to a delegate for review.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "assessmentId":
            suggest = "assessment_id"
        elif key == "assessmentName":
            suggest = "assessment_name"
        elif key == "controlSetId":
            suggest = "control_set_id"
        elif key == "createdBy":
            suggest = "created_by"
        elif key == "creationTime":
            suggest = "creation_time"
        elif key == "lastUpdated":
            suggest = "last_updated"
        elif key == "roleArn":
            suggest = "role_arn"
        elif key == "roleType":
            suggest = "role_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AssessmentDelegation. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AssessmentDelegation.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AssessmentDelegation.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 assessment_id: Optional[str] = None,
                 assessment_name: Optional[str] = None,
                 comment: Optional[str] = None,
                 control_set_id: Optional[str] = None,
                 created_by: Optional[str] = None,
                 creation_time: Optional[float] = None,
                 id: Optional[str] = None,
                 last_updated: Optional[float] = None,
                 role_arn: Optional[str] = None,
                 role_type: Optional['AssessmentRoleType'] = None,
                 status: Optional['AssessmentDelegationStatus'] = None):
        """
        The assignment of a control set to a delegate for review.
        """
        if assessment_id is not None:
            pulumi.set(__self__, "assessment_id", assessment_id)
        if assessment_name is not None:
            pulumi.set(__self__, "assessment_name", assessment_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if control_set_id is not None:
            pulumi.set(__self__, "control_set_id", control_set_id)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if role_type is not None:
            pulumi.set(__self__, "role_type", role_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="assessmentId")
    def assessment_id(self) -> Optional[str]:
        return pulumi.get(self, "assessment_id")

    @property
    @pulumi.getter(name="assessmentName")
    def assessment_name(self) -> Optional[str]:
        return pulumi.get(self, "assessment_name")

    @property
    @pulumi.getter
    def comment(self) -> Optional[str]:
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="controlSetId")
    def control_set_id(self) -> Optional[str]:
        return pulumi.get(self, "control_set_id")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[str]:
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[float]:
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[float]:
        return pulumi.get(self, "last_updated")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[str]:
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="roleType")
    def role_type(self) -> Optional['AssessmentRoleType']:
        return pulumi.get(self, "role_type")

    @property
    @pulumi.getter
    def status(self) -> Optional['AssessmentDelegationStatus']:
        return pulumi.get(self, "status")


@pulumi.output_type
class AssessmentRole(dict):
    """
    The wrapper that contains AWS Audit Manager role information, such as the role type and IAM ARN.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "roleArn":
            suggest = "role_arn"
        elif key == "roleType":
            suggest = "role_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AssessmentRole. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AssessmentRole.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AssessmentRole.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 role_arn: Optional[str] = None,
                 role_type: Optional['AssessmentRoleType'] = None):
        """
        The wrapper that contains AWS Audit Manager role information, such as the role type and IAM ARN.
        """
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if role_type is not None:
            pulumi.set(__self__, "role_type", role_type)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[str]:
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="roleType")
    def role_type(self) -> Optional['AssessmentRoleType']:
        return pulumi.get(self, "role_type")


@pulumi.output_type
class AssessmentScope(dict):
    """
    The wrapper that contains the AWS accounts and AWS services in scope for the assessment.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "awsAccounts":
            suggest = "aws_accounts"
        elif key == "awsServices":
            suggest = "aws_services"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AssessmentScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AssessmentScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AssessmentScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 aws_accounts: Optional[Sequence['outputs.AssessmentAWSAccount']] = None,
                 aws_services: Optional[Sequence['outputs.AssessmentAWSService']] = None):
        """
        The wrapper that contains the AWS accounts and AWS services in scope for the assessment.
        :param Sequence['AssessmentAWSAccount'] aws_accounts: The AWS accounts included in scope.
        :param Sequence['AssessmentAWSService'] aws_services: The AWS services included in scope.
        """
        if aws_accounts is not None:
            pulumi.set(__self__, "aws_accounts", aws_accounts)
        if aws_services is not None:
            pulumi.set(__self__, "aws_services", aws_services)

    @property
    @pulumi.getter(name="awsAccounts")
    def aws_accounts(self) -> Optional[Sequence['outputs.AssessmentAWSAccount']]:
        """
        The AWS accounts included in scope.
        """
        return pulumi.get(self, "aws_accounts")

    @property
    @pulumi.getter(name="awsServices")
    def aws_services(self) -> Optional[Sequence['outputs.AssessmentAWSService']]:
        """
        The AWS services included in scope.
        """
        return pulumi.get(self, "aws_services")


@pulumi.output_type
class AssessmentTag(dict):
    """
    A key-value pair to associate with a resource.
    """
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        A key-value pair to associate with a resource.
        :param str key: The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. 
        :param str value: The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. 
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. 
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value for the tag. You can specify a value that is 1 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -. 
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from ._enums import *

__all__ = [
    'FindingsFilterCriterionArgs',
    'FindingsFilterFindingCriteriaArgs',
]

@pulumi.input_type
class FindingsFilterCriterionArgs:
    def __init__(__self__):
        """
        Map of filter criteria.
        """
        pass


@pulumi.input_type
class FindingsFilterFindingCriteriaArgs:
    def __init__(__self__, *,
                 criterion: Optional[pulumi.Input['FindingsFilterCriterionArgs']] = None):
        if criterion is not None:
            pulumi.set(__self__, "criterion", criterion)

    @property
    @pulumi.getter
    def criterion(self) -> Optional[pulumi.Input['FindingsFilterCriterionArgs']]:
        return pulumi.get(self, "criterion")

    @criterion.setter
    def criterion(self, value: Optional[pulumi.Input['FindingsFilterCriterionArgs']]):
        pulumi.set(self, "criterion", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LaunchConfigurationArgs', 'LaunchConfiguration']

@pulumi.input_type
class LaunchConfigurationArgs:
    def __init__(__self__, *,
                 image_id: pulumi.Input[str],
                 instance_type: pulumi.Input[str],
                 associate_public_ip_address: Optional[pulumi.Input[bool]] = None,
                 block_device_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchConfigurationBlockDeviceMappingArgs']]]] = None,
                 classic_link_vpc_id: Optional[pulumi.Input[str]] = None,
                 classic_link_vpc_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ebs_optimized: Optional[pulumi.Input[bool]] = None,
                 iam_instance_profile: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 instance_monitoring: Optional[pulumi.Input[bool]] = None,
                 kernel_id: Optional[pulumi.Input[str]] = None,
                 key_name: Optional[pulumi.Input[str]] = None,
                 launch_configuration_name: Optional[pulumi.Input[str]] = None,
                 metadata_options: Optional[pulumi.Input['LaunchConfigurationMetadataOptionsArgs']] = None,
                 placement_tenancy: Optional[pulumi.Input[str]] = None,
                 ram_disk_id: Optional[pulumi.Input[str]] = None,
                 security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 spot_price: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LaunchConfiguration resource.
        """
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "instance_type", instance_type)
        if associate_public_ip_address is not None:
            pulumi.set(__self__, "associate_public_ip_address", associate_public_ip_address)
        if block_device_mappings is not None:
            pulumi.set(__self__, "block_device_mappings", block_device_mappings)
        if classic_link_vpc_id is not None:
            pulumi.set(__self__, "classic_link_vpc_id", classic_link_vpc_id)
        if classic_link_vpc_security_groups is not None:
            pulumi.set(__self__, "classic_link_vpc_security_groups", classic_link_vpc_security_groups)
        if ebs_optimized is not None:
            pulumi.set(__self__, "ebs_optimized", ebs_optimized)
        if iam_instance_profile is not None:
            pulumi.set(__self__, "iam_instance_profile", iam_instance_profile)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_monitoring is not None:
            pulumi.set(__self__, "instance_monitoring", instance_monitoring)
        if kernel_id is not None:
            pulumi.set(__self__, "kernel_id", kernel_id)
        if key_name is not None:
            pulumi.set(__self__, "key_name", key_name)
        if launch_configuration_name is not None:
            pulumi.set(__self__, "launch_configuration_name", launch_configuration_name)
        if metadata_options is not None:
            pulumi.set(__self__, "metadata_options", metadata_options)
        if placement_tenancy is not None:
            pulumi.set(__self__, "placement_tenancy", placement_tenancy)
        if ram_disk_id is not None:
            pulumi.set(__self__, "ram_disk_id", ram_disk_id)
        if security_groups is not None:
            pulumi.set(__self__, "security_groups", security_groups)
        if spot_price is not None:
            pulumi.set(__self__, "spot_price", spot_price)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "associate_public_ip_address")

    @associate_public_ip_address.setter
    def associate_public_ip_address(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "associate_public_ip_address", value)

    @property
    @pulumi.getter(name="blockDeviceMappings")
    def block_device_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchConfigurationBlockDeviceMappingArgs']]]]:
        return pulumi.get(self, "block_device_mappings")

    @block_device_mappings.setter
    def block_device_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchConfigurationBlockDeviceMappingArgs']]]]):
        pulumi.set(self, "block_device_mappings", value)

    @property
    @pulumi.getter(name="classicLinkVPCId")
    def classic_link_vpc_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "classic_link_vpc_id")

    @classic_link_vpc_id.setter
    def classic_link_vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "classic_link_vpc_id", value)

    @property
    @pulumi.getter(name="classicLinkVPCSecurityGroups")
    def classic_link_vpc_security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "classic_link_vpc_security_groups")

    @classic_link_vpc_security_groups.setter
    def classic_link_vpc_security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "classic_link_vpc_security_groups", value)

    @property
    @pulumi.getter(name="ebsOptimized")
    def ebs_optimized(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "ebs_optimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ebs_optimized", value)

    @property
    @pulumi.getter(name="iamInstanceProfile")
    def iam_instance_profile(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "iam_instance_profile")

    @iam_instance_profile.setter
    def iam_instance_profile(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "iam_instance_profile", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceMonitoring")
    def instance_monitoring(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "instance_monitoring")

    @instance_monitoring.setter
    def instance_monitoring(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "instance_monitoring", value)

    @property
    @pulumi.getter(name="kernelId")
    def kernel_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "kernel_id")

    @kernel_id.setter
    def kernel_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kernel_id", value)

    @property
    @pulumi.getter(name="keyName")
    def key_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "key_name")

    @key_name.setter
    def key_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_name", value)

    @property
    @pulumi.getter(name="launchConfigurationName")
    def launch_configuration_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "launch_configuration_name")

    @launch_configuration_name.setter
    def launch_configuration_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "launch_configuration_name", value)

    @property
    @pulumi.getter(name="metadataOptions")
    def metadata_options(self) -> Optional[pulumi.Input['LaunchConfigurationMetadataOptionsArgs']]:
        return pulumi.get(self, "metadata_options")

    @metadata_options.setter
    def metadata_options(self, value: Optional[pulumi.Input['LaunchConfigurationMetadataOptionsArgs']]):
        pulumi.set(self, "metadata_options", value)

    @property
    @pulumi.getter(name="placementTenancy")
    def placement_tenancy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "placement_tenancy")

    @placement_tenancy.setter
    def placement_tenancy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_tenancy", value)

    @property
    @pulumi.getter(name="ramDiskId")
    def ram_disk_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ram_disk_id")

    @ram_disk_id.setter
    def ram_disk_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ram_disk_id", value)

    @property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "security_groups")

    @security_groups.setter
    def security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_groups", value)

    @property
    @pulumi.getter(name="spotPrice")
    def spot_price(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "spot_price")

    @spot_price.setter
    def spot_price(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spot_price", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_data", value)


warnings.warn("""LaunchConfiguration is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)


class LaunchConfiguration(pulumi.CustomResource):
    warnings.warn("""LaunchConfiguration is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associate_public_ip_address: Optional[pulumi.Input[bool]] = None,
                 block_device_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LaunchConfigurationBlockDeviceMappingArgs']]]]] = None,
                 classic_link_vpc_id: Optional[pulumi.Input[str]] = None,
                 classic_link_vpc_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ebs_optimized: Optional[pulumi.Input[bool]] = None,
                 iam_instance_profile: Optional[pulumi.Input[str]] = None,
                 image_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 instance_monitoring: Optional[pulumi.Input[bool]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 kernel_id: Optional[pulumi.Input[str]] = None,
                 key_name: Optional[pulumi.Input[str]] = None,
                 launch_configuration_name: Optional[pulumi.Input[str]] = None,
                 metadata_options: Optional[pulumi.Input[pulumi.InputType['LaunchConfigurationMetadataOptionsArgs']]] = None,
                 placement_tenancy: Optional[pulumi.Input[str]] = None,
                 ram_disk_id: Optional[pulumi.Input[str]] = None,
                 security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 spot_price: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Resource Type definition for AWS::AutoScaling::LaunchConfiguration

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LaunchConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource Type definition for AWS::AutoScaling::LaunchConfiguration

        :param str resource_name: The name of the resource.
        :param LaunchConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LaunchConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associate_public_ip_address: Optional[pulumi.Input[bool]] = None,
                 block_device_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LaunchConfigurationBlockDeviceMappingArgs']]]]] = None,
                 classic_link_vpc_id: Optional[pulumi.Input[str]] = None,
                 classic_link_vpc_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ebs_optimized: Optional[pulumi.Input[bool]] = None,
                 iam_instance_profile: Optional[pulumi.Input[str]] = None,
                 image_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 instance_monitoring: Optional[pulumi.Input[bool]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 kernel_id: Optional[pulumi.Input[str]] = None,
                 key_name: Optional[pulumi.Input[str]] = None,
                 launch_configuration_name: Optional[pulumi.Input[str]] = None,
                 metadata_options: Optional[pulumi.Input[pulumi.InputType['LaunchConfigurationMetadataOptionsArgs']]] = None,
                 placement_tenancy: Optional[pulumi.Input[str]] = None,
                 ram_disk_id: Optional[pulumi.Input[str]] = None,
                 security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 spot_price: Optional[pulumi.Input[str]] = None,
                 user_data: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""LaunchConfiguration is deprecated: LaunchConfiguration is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""")
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LaunchConfigurationArgs.__new__(LaunchConfigurationArgs)

            __props__.__dict__["associate_public_ip_address"] = associate_public_ip_address
            __props__.__dict__["block_device_mappings"] = block_device_mappings
            __props__.__dict__["classic_link_vpc_id"] = classic_link_vpc_id
            __props__.__dict__["classic_link_vpc_security_groups"] = classic_link_vpc_security_groups
            __props__.__dict__["ebs_optimized"] = ebs_optimized
            __props__.__dict__["iam_instance_profile"] = iam_instance_profile
            if image_id is None and not opts.urn:
                raise TypeError("Missing required property 'image_id'")
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["instance_monitoring"] = instance_monitoring
            if instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type'")
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["kernel_id"] = kernel_id
            __props__.__dict__["key_name"] = key_name
            __props__.__dict__["launch_configuration_name"] = launch_configuration_name
            __props__.__dict__["metadata_options"] = metadata_options
            __props__.__dict__["placement_tenancy"] = placement_tenancy
            __props__.__dict__["ram_disk_id"] = ram_disk_id
            __props__.__dict__["security_groups"] = security_groups
            __props__.__dict__["spot_price"] = spot_price
            __props__.__dict__["user_data"] = user_data
        super(LaunchConfiguration, __self__).__init__(
            'aws-native:autoscaling:LaunchConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'LaunchConfiguration':
        """
        Get an existing LaunchConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = LaunchConfigurationArgs.__new__(LaunchConfigurationArgs)

        __props__.__dict__["associate_public_ip_address"] = None
        __props__.__dict__["block_device_mappings"] = None
        __props__.__dict__["classic_link_vpc_id"] = None
        __props__.__dict__["classic_link_vpc_security_groups"] = None
        __props__.__dict__["ebs_optimized"] = None
        __props__.__dict__["iam_instance_profile"] = None
        __props__.__dict__["image_id"] = None
        __props__.__dict__["instance_id"] = None
        __props__.__dict__["instance_monitoring"] = None
        __props__.__dict__["instance_type"] = None
        __props__.__dict__["kernel_id"] = None
        __props__.__dict__["key_name"] = None
        __props__.__dict__["launch_configuration_name"] = None
        __props__.__dict__["metadata_options"] = None
        __props__.__dict__["placement_tenancy"] = None
        __props__.__dict__["ram_disk_id"] = None
        __props__.__dict__["security_groups"] = None
        __props__.__dict__["spot_price"] = None
        __props__.__dict__["user_data"] = None
        return LaunchConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "associate_public_ip_address")

    @property
    @pulumi.getter(name="blockDeviceMappings")
    def block_device_mappings(self) -> pulumi.Output[Optional[Sequence['outputs.LaunchConfigurationBlockDeviceMapping']]]:
        return pulumi.get(self, "block_device_mappings")

    @property
    @pulumi.getter(name="classicLinkVPCId")
    def classic_link_vpc_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "classic_link_vpc_id")

    @property
    @pulumi.getter(name="classicLinkVPCSecurityGroups")
    def classic_link_vpc_security_groups(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "classic_link_vpc_security_groups")

    @property
    @pulumi.getter(name="ebsOptimized")
    def ebs_optimized(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "ebs_optimized")

    @property
    @pulumi.getter(name="iamInstanceProfile")
    def iam_instance_profile(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "iam_instance_profile")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceMonitoring")
    def instance_monitoring(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "instance_monitoring")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="kernelId")
    def kernel_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "kernel_id")

    @property
    @pulumi.getter(name="keyName")
    def key_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "key_name")

    @property
    @pulumi.getter(name="launchConfigurationName")
    def launch_configuration_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "launch_configuration_name")

    @property
    @pulumi.getter(name="metadataOptions")
    def metadata_options(self) -> pulumi.Output[Optional['outputs.LaunchConfigurationMetadataOptions']]:
        return pulumi.get(self, "metadata_options")

    @property
    @pulumi.getter(name="placementTenancy")
    def placement_tenancy(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "placement_tenancy")

    @property
    @pulumi.getter(name="ramDiskId")
    def ram_disk_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "ram_disk_id")

    @property
    @pulumi.getter(name="securityGroups")
    def security_groups(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "security_groups")

    @property
    @pulumi.getter(name="spotPrice")
    def spot_price(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "spot_price")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "user_data")

